package com.gic.haoban.manage.service.service.out.impl;

import java.util.List;
import java.util.Set;

import com.alibaba.fastjson.JSON;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.PageUtil;

import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.haoban.manage.api.dto.QywxCorpInfoSimpleDTO;
import com.gic.haoban.manage.api.dto.WxEnterpriseDTO;
import com.gic.haoban.manage.api.dto.YwWxEnterpriseDTO;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseApiService;
import com.gic.haoban.manage.service.dao.mapper.WxEnterpriseMapper;
import com.gic.haoban.manage.service.entity.TabHaobanWxApplication;
import com.gic.haoban.manage.service.entity.TabHaobanWxEnterprise;
import com.gic.haoban.manage.service.service.WxApplicationService;
import com.gic.haoban.manage.service.service.WxEnterpriseService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;

@Service
public class WxEnterpriseApiServiceImpl implements WxEnterpriseApiService {
	private static final Logger log = LogManager.getLogger(WxEnterpriseApiServiceImpl.class);
	@Autowired
	private WxEnterpriseService wxEnterpriseService;
	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private WxEnterpriseMapper wxEnterpriseMapper;
	@Autowired
	private WxApplicationService wxApplicationService;
	
	@Autowired
	private EnterpriseService enterpriseService;
	
	@Override
	public void callbackReviceEnterprise(QywxCorpInfoSimpleDTO dto) {
		log.info("企业微信授权信息：{}", JSON.toJSONString(dto));
		WxEnterpriseDTO wxDTO = EntityUtil.changeEntityByJSON(WxEnterpriseDTO.class, dto);
		TabHaobanWxEnterprise enterprise = this.wxEnterpriseService.getEnterpriseBycorpIdNoStatus(dto.getCorpid());
		String wxEnterpriseId = "";
		if(enterprise != null){
			wxEnterpriseId = enterprise.getWxEnterpriseId();
			wxDTO.setWxEnterpriseId(enterprise.getWxEnterpriseId());
			wxDTO.setStatusFlag(1);
			wxEnterpriseService.update(wxDTO);
		}else{
			wxEnterpriseId = wxEnterpriseService.add(wxDTO);
		}
		String userId = dto.getUserid();
		String name = dto.getName();
		if(StringUtils.isNotBlank(userId)) {
			staffApiService.wxGetAdd(userId,wxEnterpriseId);
		}
		String siteId = dto.getSuiteId();
		String agentId = dto.getAgentid();
		String agentName = dto.getAgentName();
		String permanentCode = dto.getPermanentCode();
		String applicationName = dto.getName();
		
		TabHaobanWxApplication tab = wxApplicationService.selectBySiteIdAndWxEnterpriseId(siteId,wxEnterpriseId);
		if(tab == null) {
			tab = new TabHaobanWxApplication();
			tab.setAgentId(agentId);
			tab.setSiteId(siteId);
			tab.setAgentName(agentName);
			tab.setName(applicationName);
			tab.setPermanentCode(permanentCode);
			tab.setWxEnterpriseId(wxEnterpriseId);
			wxApplicationService.insert(tab);
		}else {
			tab.setPermanentCode(permanentCode);
			wxApplicationService.update(tab);
		}
		log.info("企业微信授权处理完成");
	}

	@Override
	public com.gic.api.base.commons.Page<YwWxEnterpriseDTO> list(BasePageInfo pageInfo,String keyword,List<String> enterpriseIds,Integer gicContactFlag,String version) {
		PageHelper.startPage(pageInfo.getPageNum(), pageInfo.getPageSize());
		Page<TabHaobanWxEnterprise>  page = wxEnterpriseMapper.list(keyword,enterpriseIds,gicContactFlag,version);
		return  PageUtil.changePageHelperToCurrentPage(page, YwWxEnterpriseDTO.class);
	}
	
	@Override
	public List<YwWxEnterpriseDTO> listAll() {
		List<TabHaobanWxEnterprise>  list = wxEnterpriseMapper.listAll();
		return  EntityUtil.changeEntityListByJSON(YwWxEnterpriseDTO.class, list);
	}
	
	@Override
	public List<YwWxEnterpriseDTO> listByIds(Set<String> enterpriseIds) {
		List<TabHaobanWxEnterprise>  list = wxEnterpriseMapper.listByIds(enterpriseIds);
		return  EntityUtil.changeEntityListByJSON(YwWxEnterpriseDTO.class, list);
	}

	@Override
	public WxEnterpriseDTO getOne(String wxEnterpriseId) {
		TabHaobanWxEnterprise tab = wxEnterpriseMapper.selectByPrimaryKey(wxEnterpriseId);
		WxEnterpriseDTO wxDTO = EntityUtil.changeEntityByJSON(WxEnterpriseDTO.class, tab);
		return wxDTO;
	}

	@Override
	public WxEnterpriseDTO getEnterpriseBycorpId(String corpId) {
		TabHaobanWxEnterprise enterprise = this.wxEnterpriseService.getEnterpriseBycorpId(corpId);
		return EntityUtil.changeEntityByJSON(WxEnterpriseDTO.class, enterprise);
	}

	@Override
	public void update(WxEnterpriseDTO enterpriseDTO) {
		wxEnterpriseService.update(enterpriseDTO);
		
	}
	
	@Override
	public boolean enterpriseIsOver(String enterpriseId) {
		if(StringUtils.isEmpty(enterpriseId)){
			return true;
		}
		EnterpriseDTO enterprise = enterpriseService.getEnterpriseByEid(enterpriseId);
		if(enterprise == null || enterprise.getExpireTime() == null){
			return true;
		}
		if(enterprise.getExpireTime().getTime() > System.currentTimeMillis()){
			return false;
		}
		return true;
		
	}
}
