package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.dto.ClerkListDTO;
import com.gic.clerk.api.service.ClerkNewService;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.DateUtil;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.app.customer.service.api.service.DistributeApiService;
import com.gic.haoban.base.api.common.ShowFrontMessageException;
import com.gic.haoban.common.utils.GooglePhoneNumberUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.communicate.api.service.SyncHaobanToGicServiceApi;
import com.gic.haoban.manage.api.dto.AuditDTO;
import com.gic.haoban.manage.api.dto.AuditSettingDTO;
import com.gic.haoban.manage.api.dto.ClerkMainStoreRelatedDTO;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.EnterpriseDetailDTO;
import com.gic.haoban.manage.api.dto.MemberUnionidRelatedDTO;
import com.gic.haoban.manage.api.dto.StaffClerkRelationDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.dto.WxEnterpriseDTO;
import com.gic.haoban.manage.api.enums.AppPageType;
import com.gic.haoban.manage.api.enums.AuditType;
import com.gic.haoban.manage.api.service.AuditApiService;
import com.gic.haoban.manage.api.service.AuditSettingApiService;
import com.gic.haoban.manage.api.service.BindApiService;
import com.gic.haoban.manage.api.service.ClerkMainStoreRelatedApiService;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.MemberUnionidRelatedApiService;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.api.service.StaffClerkRelationApiService;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.web.anno.HttpLimit;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.interceptor.WebInterceptor;
import com.gic.haoban.manage.web.vo.BindClerkVO;
import com.gic.haoban.manage.web.vo.ClerkStoreVO;
import com.gic.haoban.manage.web.vo.ClerkVo;
import com.gic.haoban.manage.web.vo.StaffStoreVO;
import com.gic.haoban.manage.web.vo.StoreClerkVO;
import com.gic.redis.data.util.RedisUtil;
import com.gic.wechat.api.service.qywx.QywxUserApiService;
import com.google.i18n.phonenumbers.PhoneNumberUtil;

@RestController
public class ClerkController extends WebBaseController{
    private static Logger logger= LoggerFactory.getLogger(ClerkController.class);

	@Autowired
	private ClerkService clerkService;
	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;
	@Autowired
	private StoreService storeService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private BindApiService bindApiService;
	@Autowired
	private SyncHaobanToGicServiceApi syncHaobanToGicServiceApi;
	@Autowired
	private ClerkMainStoreRelatedApiService clerkMainStoreRelatedApiService;
	@Autowired
	private DistributeApiService distributeApiService;
	@Autowired
	private MemberUnionidRelatedApiService memberUnionidRelatedApiService;
	@Autowired
	private WxEnterpriseRelatedApiService wxEnterpriseRelatedApiService;
	@Autowired
	private EnterpriseService enterpriseService;
	@Autowired
	private AuditApiService auditApiService;
	@Autowired
	private StaffClerkRelationApiService staffClerkRelationApiService;
	@Autowired
	private ClerkNewService clerkNewService;
	@Autowired
	private AuditSettingApiService auditSettingApiService;
	//选择成员列表
	@RequestMapping("/staff-list")
	public HaobanResponse staffList(String storeId) {
		if(StringUtils.isAnyBlank(storeId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		List<StaffClerkRelationDTO> list = staffClerkRelationApiService.listByStoreId(storeId);
		List<String> staffIds = list.stream().map(s->s.getStaffId()).collect(Collectors.toList());
		List<StaffDTO>  resultlist= staffApiService.listByIds(staffIds);
		Map<String,StaffClerkRelationDTO> map = com.gic.commons.util.CollectionUtil.toMap(list, "staffId");
		int size = 0;
		if(resultlist != null){
			size = resultlist.size();
		}
		for(StaffDTO dto :resultlist){
			StaffClerkRelationDTO staffClerkRelationDTO = map.get(dto.getStaffId());
			dto.setClerkCode(staffClerkRelationDTO.getClerkCode());
			dto.setClerkId(staffClerkRelationDTO.getClerkId());
			if(size < 20){
				ClerkDTO clerk = clerkService.getClerkByClerkCode(staffClerkRelationDTO.getEnterpriseId(), staffClerkRelationDTO.getClerkCode());
				if(clerk != null){
					long memberCount = distributeApiService.getClerkMemberCount(staffClerkRelationDTO.getEnterpriseId(), clerk.getClerkId(), storeId);
					logger.info("【获取会员数】enterpriseId={},clerkId={},storeId={},count={}",staffClerkRelationDTO.getEnterpriseId(),clerk.getClerkId(),storeId,memberCount);
					dto.setMemberCount(memberCount);
				}else{
					dto.setMemberCount(0);
				}
			}else{
				dto.setMemberCount(0);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,resultlist);
		
	}
	
	//门店成员列表
	@RequestMapping("/store-clerks")
	public HaobanResponse storeClerks(String storeId) {
		if(StringUtils.isAnyBlank(storeId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		StoreDTO storeDTO = storeService.getStore(storeId);
		if(storeDTO == null){
			return resultResponse(HaoBanErrCode.ERR_10009);
		}
		List<ClerkListDTO> list = clerkService.getClerkByStoreId(storeDTO.getEnterpriseId(), storeId);
		Set<String> clerkCodeList = list.stream().map(ClerkListDTO::getClerkCode).collect(Collectors.toSet());
		List<StaffClerkRelationDTO> bindRelationList = staffClerkRelationApiService.listBindCode(storeDTO.getEnterpriseId(),clerkCodeList);
		Map<String,StaffClerkRelationDTO> bindCodeMap = bindRelationList.stream().collect(Collectors.toMap(StaffClerkRelationDTO::getClerkCode, s->s));
		List<StoreClerkVO> resultList = new ArrayList<>();
		for(ClerkListDTO dto :list){
			String clerkCode = dto.getClerkCode();
			StoreClerkVO vo = new StoreClerkVO();
			vo.setClerkCode(clerkCode);
			vo.setClerkId(dto.getClerkId());
			vo.setClerkType(dto.getClerkType());
			vo.setClerkImg(dto.getImageUrl());
			vo.setClerkName(dto.getClerkName());
			StaffClerkRelationDTO related = bindCodeMap.get(clerkCode);
			if(related != null){
				vo.setStaffId(related.getStaffId());
				vo.setBindFlag(1);
			}else{
				vo.setBindFlag(0);
			}
			resultList.add(vo);
		}
		return resultResponse(HaoBanErrCode.ERR_1,resultList);
		
	}
	
	
	//新增店员
	@HttpLimit
	@RequestMapping("/staff-add")
	public HaobanResponse staffAdd(StaffDTO staffDTO,String storeId,String clerkCode,String commitName,Integer version) {
		
		String wxEnterpriseId = staffDTO.getWxEnterpriseId();
		String staffName = staffDTO.getStaffName();
		String phoneNumber = staffDTO.getPhoneNumber();
		String nationcode = staffDTO.getNationCode();
		String postion = staffDTO.getPostion();
		Integer sex = staffDTO.getSex();
		if(StringUtils.isAnyBlank(staffName,phoneNumber,commitName)) {
			return resultResponse(HaoBanErrCode.ERR_10004);
		}
		if(!GooglePhoneNumberUtil.checkPhoneNumber(phoneNumber, nationcode)){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}
		if(version == null){
			StaffDTO staff = staffApiService.selectByNationcodeAndPhoneNumber(wxEnterpriseId,nationcode,phoneNumber);
			if(staff != null) {
				return resultResponse(HaoBanErrCode.ERR_10005);
			}
		}
		com.gic.enterprise.api.dto.StoreDTO store = storeService.getStoreByIdNoStatus(storeId);
		//校验手机是否唯一
		if (store == null) {
			return resultResponse(HaoBanErrCode.ERR_10009);
		}
		ClerkDTO clerk = clerkService.getClerkByCodeNoDel(store.getEnterpriseId(), clerkCode);
		logger.info("【新增店员】clerk={}",JSON.toJSONString(clerk));
		if(clerk != null){
			return resultResponse(HaoBanErrCode.ERR_10013);
		}
		AuditSettingDTO dto = auditSettingApiService.findSettingByWxEnterpriseId(wxEnterpriseId);
		if(dto.getClerkChangeFlag() == 1){
			AuditDTO auditDTO =auditApiService.findByBindRelatedIdAndAuditType(clerkCode, AuditType.CLERK_ADD.getCode());
			if(auditDTO !=null){
				logger.info("已经存在了审核记录，待审核{}",clerkCode);
				return resultResponse(HaoBanErrCode.ERR_10018);
			}
			//需要审核
			StaffDTO staff = staffApiService.selectById(staffDTO.getStaffId());
			AuditDTO audit = new AuditDTO();
			audit.setCommitStaffName(commitName);
			audit.setCommitStaffId(staffDTO.getStaffId());
			audit.setCommitStaffImg(staff.getHeadImg());
			audit.setCommitStoreId(storeId);
			audit.setCommitStoreName(store.getStoreName());
			audit.setAuditStatus(0);
			audit.setWxEnterpriseId(wxEnterpriseId);
			audit.setEnterpriseId(store.getEnterpriseId());
			audit.setStatusFlag(1);
			
			JSONObject json = new JSONObject();
			json.put("clerkCode", clerkCode);
			json.put("clerkName", staffName);
			json.put("headPic", staff.getHeadImg());
			json.put("sex", sex);
			json.put("postion", postion);
			audit.setOldValue(json.toJSONString());
			audit.setCommitTime(new Date());
			audit.setAuditType(3);
			audit.setRelatedId(clerkCode);
			auditApiService.insert(audit);
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		//只新增gic那边的，不新增好办这边
		boolean flag = syncHaobanToGicServiceApi.syncClerkToGicClerkAdd(storeId, clerkCode, sex, staffName, phoneNumber, nationcode, postion);
		if(!flag){
			return resultResponse(HaoBanErrCode.ERR_10010);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	//删除店员
	@HttpLimit
	@RequestMapping("/staff-del")
	public HaobanResponse staffDel(String wxEnterpriseId,String storeId,Integer version,String clerkIds,String staffId) {
		AuditSettingDTO dto = auditSettingApiService.findSettingByWxEnterpriseId(wxEnterpriseId);
		if(dto.getClerkChangeFlag() == 1){
			//需要审核
			com.gic.enterprise.api.dto.StoreDTO store = storeService.getStoreByIdNoStatus(storeId);
			//校验手机是否唯一
			if (store == null) {
				return resultResponse(HaoBanErrCode.ERR_400001);
			}
			StaffDTO staff = staffApiService.selectById(staffId);
			String[] clerkIdArr = clerkIds.split(",");
			for (String clerkId : clerkIdArr) {
				AuditDTO auditDTO =auditApiService.findByBindRelatedIdAndAuditType(clerkId, AuditType.CLERK_DEL.getCode());
				if(auditDTO !=null){
					logger.info("已经存在了审核记录，待审核{}",clerkId);
					continue;
				}
				
				AuditDTO audit = new AuditDTO();
				audit.setCommitStaffName(staff.getStaffName());
				audit.setCommitStaffId(staffId);
				audit.setCommitStaffImg(staff.getHeadImg());
				audit.setCommitStoreId(storeId);
				audit.setCommitStoreName(store.getStoreName());
				audit.setAuditStatus(0);
				audit.setWxEnterpriseId(wxEnterpriseId);
				audit.setEnterpriseId(store.getEnterpriseId());
				audit.setStatusFlag(1);
				audit.setRelatedId(clerkId);

				JSONObject json = new JSONObject();
				json.put("clerkId", clerkId);
				audit.setOldValue(json.toJSONString());
				audit.setCommitTime(new Date());
				audit.setAuditType(4);
				auditApiService.insert(audit);
			}
		}else{
			//只删除gic那边的
			String[] clerkIdArr = clerkIds.split(",");
			for (String clerkId : clerkIdArr) {
				syncHaobanToGicServiceApi.delGicClerk(clerkId);
			}
		}
		
		
//		DepartmentDTO departmentDTO = departmentApiService.selectByRelatedId(storeId);
//		if(departmentDTO == null){
//			return resultResponse(HaoBanErrCode.ERR_10009);
//		}
//		if(StringUtils.isBlank(staffDepartmentRelatedIds)){
//			return resultResponse(HaoBanErrCode.ERR_2);
//		}
//		String[] staffDepartmentRelatedIdArr = staffDepartmentRelatedIds.split(",");
//		boolean flag = false;
//		for (String staffDepartmentRelatedId : staffDepartmentRelatedIdArr) {
//			StaffDepartmentRelatedDTO related = staffDepartmentRelatedApiService.getByStaffDepartmentRelatedId(staffDepartmentRelatedId);
//			if(related == null){
//				flag = true;
//				continue;
//			}
//			if(StringUtils.isBlank(related.getClerkCode())){
//				staffApiService.del(staffDepartmentRelatedId);
//			}else{
//				ClerkDTO clerk = clerkService.getClerkByClerkCode(departmentDTO.getEnterpriseId(), related.getClerkCode());
//				if(clerk != null && distributeApiService.getClerkMemberCount(departmentDTO.getEnterpriseId(), clerk.getClerkId(), storeId) == 0){
//					if(clerk.getClerkType() == 1){
//						continue;
//					}
//					syncHaobanToGicServiceApi.delGicClerk(clerk.getClerkId());
//					staffApiService.del(staffDepartmentRelatedId);
//				}
//			}
//		}
//		if(flag){
//			return resultResponse(HaoBanErrCode.ERR_999);
//		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	
	//设置主导购
	@HttpLimit
	@RequestMapping("/set-main-store")
	public HaobanResponse setMainStore(String staffId,String storeId,String wxEnterpriseId ) {
		StaffDTO staff = staffApiService.selectById(staffId);
		String yyyyMM = DateUtil.dateToStr(new Date(), "yyyyMM");
		if(staff == null){
			return resultResponse(HaoBanErrCode.ERR_10006);
		}
		String key = "haoban_set_main_store_" + yyyyMM + staffId;
		Object hasSet = RedisUtil.getCache(key);
		if(hasSet == null){
			RedisUtil.setCache(key,true,31 * 24 * 60 * 60l);
			clerkMainStoreRelatedApiService.setMainStore(staffId,storeId,wxEnterpriseId);
		}else{
			return resultResponse(HaoBanErrCode.ERR_10007);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	//刷新微信好友
	@RequestMapping("/fresh-wx-friend")
	public HaobanResponse freshWxFrend(String staffId,String storeId,String wxEnterpriseId,String staffDepartmentRelatedId,String wxUserId) {
		StaffDTO staff = staffApiService.selectById(staffId);
		String yyyyMM = DateUtil.dateToStr(new Date(), "yyyyMM");
		if(staff == null){
			return resultResponse(HaoBanErrCode.ERR_10006);
		}
		String key = "haoban_fresh_wx_friend" + yyyyMM + staffId;
		Integer count =  RedisUtil.getCache(key) == null ? 0 : (Integer)RedisUtil.getCache(key);
		if(count == null || count < 4){
			RedisUtil.setCache(key,count + 1,31 * 24 * 60 * 60l);
			memberUnionidRelatedApiService.freshWxFrend(wxEnterpriseId, staff.getWxUserId());
			
		}else{
			return resultResponse(HaoBanErrCode.ERR_10011);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//精确查，根据手机号或者code，查找
	@RequestMapping("query-clerk-list-by-code")
	public HaobanResponse queryClerkListByCode(String keyword,String wxEnterpriseId){
		if(StringUtils.isAnyBlank(keyword,wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		List<EnterpriseDetailDTO> list = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(wxEnterpriseId);
		if(list == null || list.isEmpty()){
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		List<String> enterpriseIdList = list.stream().map(s->s.getEnterpriseId()).collect(Collectors.toList());
		List<ClerkDTO> clerkList = clerkNewService.listClerkByEnterpriseIdAndSearch(enterpriseIdList,  keyword);
		List<ClerkStoreVO> clerkStoreList = new ArrayList<>();
		if(CollectionUtil.isEmpty(clerkList)){
			return resultResponse(HaoBanErrCode.ERR_1,clerkStoreList);
		}
		List<EnterpriseDTO> enterpriselist = enterpriseService.listEnterpriseByIds(enterpriseIdList);
		Map<String,EnterpriseDTO> map = com.gic.commons.util.CollectionUtil.toMap(enterpriselist,"enterpriseId");
		List<String> clerkIds = clerkList.stream().map(s->s.getClerkId()).collect(Collectors.toList());
		List<StaffClerkRelationDTO> clerkRelations = staffClerkRelationApiService.listByClerkIds(clerkIds);
		Map<String,StaffClerkRelationDTO> clerkBindMap = com.gic.commons.util.CollectionUtil.toMap(clerkRelations, "clerkId");
		
		for (ClerkDTO clerk : clerkList) {
			String enterpriseId = clerk.getEnterpriseId();
			EnterpriseDTO enterpriseDTO = map.get(enterpriseId);
			StaffClerkRelationDTO staffClerkRelationDTO = clerkBindMap.get(clerk.getClerkId());
			
			ClerkStoreVO vo = new ClerkStoreVO();
			vo.setClerkId(clerk.getClerkId());
			vo.setClerkCode(clerk.getClerkCode());
			vo.setClerkName(clerk.getClerkName());
			vo.setClerkType(clerk.getClerkType());
			vo.setEnterpriseName(enterpriseDTO == null?"":enterpriseDTO.getEnterpriseName());
			vo.setHeadImg(clerk.getHeadImgUrl());
			vo.setPhoneNumber(clerk.getPhoneNumber());
			vo.setNationCode(clerk.getNationcode());
			StoreDTO store = storeService.getStore(clerk.getStoreId());
			vo.setStoreName(store == null?"":store.getStoreName());
			vo.setStoreAddress(store == null?"":store.getStoreAddress());
			vo.setBindFlag(staffClerkRelationDTO==null ? 0:1);
			vo.setStaffId(staffClerkRelationDTO==null ? "":staffClerkRelationDTO.getStaffId());
			vo.setStoreId(clerk.getStoreId());
			clerkStoreList.add(vo);
		}
		return resultResponse(HaoBanErrCode.ERR_1,clerkStoreList);
	}
	//绑定
	@RequestMapping("bind-staff")
	public HaobanResponse bindStaff(String clerkId,String staffId,Integer auditType){
		if(StringUtils.isAnyBlank(clerkId,staffId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		if(auditType == null ){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		ClerkDTO clerk = clerkService.getclerkById(clerkId);
		if(clerk == null){
			return resultResponse(HaoBanErrCode.ERR_10016);
		}
		StaffDTO staff = staffApiService.selectById(staffId);
		if(staff == null){
			return resultResponse(HaoBanErrCode.ERR_10006);
		}
		AuditDTO auditDTO = auditApiService.findByBindRelatedIdAndAuditType(clerk.getClerkCode(),AuditType.CLERK_BIND.getCode());
		if(auditDTO != null){
			return resultResponse(HaoBanErrCode.ERR_10018);
		}
		StoreDTO store = storeService.getStore(clerk.getStoreId());
		String clerkCode = clerk.getClerkCode();
		String wxEnterpriseId = staff.getWxEnterpriseId();
		String wxUserId = staff.getWxUserId();
		StaffClerkRelationDTO staffClerkRelation  = staffClerkRelationApiService.getByCodeAndEnterpriseId(clerkCode,store.getEnterpriseId());
		if(staffClerkRelation != null){
			return resultResponse(HaoBanErrCode.ERR_111117);
		}
		if(auditType == 2){
			//无需审核
			staffClerkRelation = new StaffClerkRelationDTO();
			staffClerkRelation.setClerkId(clerkId);
			staffClerkRelation.setClerkCode(clerkCode);
			staffClerkRelation.setStoreId(clerk.getStoreId());
			staffClerkRelation.setEnterpriseId(clerk.getEnterpriseId());
			staffClerkRelation.setWxEnterpriseId(wxEnterpriseId);
			staffClerkRelation.setWxUserId(wxUserId);
			staffClerkRelation.setStaffId(staffId);
			staffClerkRelationApiService.insert(staffClerkRelation);
			
			//无需审核
			AuditDTO audit = new AuditDTO();
			audit.setCommitStaffName(clerk.getClerkName());
			audit.setCommitStaffId(staffId);
			audit.setCommitStaffImg(staff.getHeadImg());
			audit.setCommitStoreId(clerk.getStoreId());
			audit.setCommitStoreName(store.getStoreName());
			audit.setAuditStatus(4);
			audit.setWxEnterpriseId(wxEnterpriseId);
			audit.setEnterpriseId(store.getEnterpriseId());
			audit.setStatusFlag(1);
			audit.setRelatedId(clerkCode);

			JSONObject json = new JSONObject();
			json.put("clerkId", clerkId);
			json.put("clerkCode", clerkCode);
			json.put("clerkName", clerk.getClerkName());
			json.put("staffName", staff.getStaffName());
			json.put("staffId", staffId);
			json.put("wxUserId", wxUserId);
			json.put("headPic", staff.getHeadImg());
			audit.setOldValue(json.toJSONString());
			audit.setCommitTime(new Date());
			audit.setAuditType(2);
			auditApiService.insert(audit);
			//返回一个dto给陈大爷
			StaffClerkRelationDTO resultDTO  = staffClerkRelationApiService.getByCodeAndEnterpriseId(clerkCode, clerk.getEnterpriseId());
			return resultResponse(HaoBanErrCode.ERR_1,resultDTO);
		}else{
			//需要审核
			AuditDTO audit = new AuditDTO();
			audit.setCommitStaffName(clerk.getClerkName());
			audit.setCommitStaffId(staffId);
			audit.setCommitStaffImg(staff.getHeadImg());
			audit.setCommitStoreId(clerk.getStoreId());
			audit.setCommitStoreName(store.getStoreName());
			audit.setAuditStatus(0);
			audit.setWxEnterpriseId(wxEnterpriseId);
			audit.setEnterpriseId(store.getEnterpriseId());
			audit.setStatusFlag(1);
			audit.setRelatedId(clerkCode);

			JSONObject json = new JSONObject();
			json.put("clerkId", clerkId);
			json.put("clerkCode", clerkCode);
			json.put("clerkName", clerk.getClerkName());
			json.put("staffName", staff.getStaffName());
			json.put("staffId", staffId);
			json.put("wxUserId", wxUserId);
			json.put("headPic", staff.getHeadImg());
			audit.setOldValue(json.toJSONString());
			audit.setCommitTime(new Date());
			audit.setAuditType(2);
			auditApiService.insert(audit);
			
            //TODO huang 发送店长，门店关联记录列表
            String messageTitle = "门店账号申请";
    		String messageContent = clerk.getClerkName()+"申请关联导购code（"+clerkCode+"）";
    		JSONObject jsonObject = new JSONObject();
    		jsonObject.put("storeId", clerk.getStoreId());
    		String data = jsonObject.toJSONString();
            ClerkDTO gicClerk = clerkService.getClerkLeaderByStoreId(clerk.getStoreId());
    		String pageUrl = staffDepartmentRelatedApiService.getPageUrl(AppPageType.STORE_RELATED_RECORD.getCode(), data);
    		staffDepartmentRelatedApiService.sendSingleMessage(gicClerk.getClerkId(), messageTitle, messageContent, pageUrl);

			return resultResponse(HaoBanErrCode.ERR_1);
		}
	}
	//解绑
	@RequestMapping("unbind-staff")
	public HaobanResponse unBindStaff(String clerkId,String clerkCode,String staffId,String storeId){
		if(StringUtils.isAnyBlank(clerkId,clerkCode,staffId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		ClerkDTO clerk = clerkService.getclerkById(clerkId);
		if(clerk == null){
			return resultResponse(HaoBanErrCode.ERR_10016);
		}
		StaffDTO staff = staffApiService.selectById(staffId);
		if(staff == null){
			return resultResponse(HaoBanErrCode.ERR_10006);
		}
		StoreDTO store = storeService.getStore(clerk.getStoreId());
		StaffClerkRelationDTO staffClerkRelation  = staffClerkRelationApiService.getByCodeAndEnterpriseId(clerkCode,store.getEnterpriseId());
		if(staffClerkRelation == null){
			return resultResponse(HaoBanErrCode.ERR_111145);
		}
		
		//解绑无需审核，只插入记录即可
		AuditDTO audit = new AuditDTO();
		audit.setCommitStaffName(clerk.getClerkName());
		audit.setCommitStaffId(staffId);
		audit.setCommitStaffImg(staff.getHeadImg());
		audit.setCommitStoreId(clerk.getStoreId());
		audit.setCommitStoreName(store.getStoreName());
		audit.setAuditStatus(1);
		audit.setWxEnterpriseId(staffClerkRelation.getWxEnterpriseId());
		audit.setEnterpriseId(store.getEnterpriseId());
		audit.setStatusFlag(1);
		audit.setRelatedId(staffId);
		audit.setRelatedId(clerkCode);

		JSONObject json = new JSONObject();
		json.put("clerkId", clerkId);
		json.put("clerkCode", clerkCode);
		json.put("clerkName", clerk.getClerkName());
		json.put("staffName", staff.getStaffName());
		json.put("staffId", staffId);
		json.put("headPic", staff.getHeadImg());
		audit.setOldValue(json.toJSONString());
		audit.setCommitTime(new Date());
		audit.setAuditName(staff.getStaffName());
		audit.setAuditType(5);
		auditApiService.insert(audit);
		
		staffClerkRelationApiService.delByStoreIdAndCode(storeId, clerkCode);
		return resultResponse(HaoBanErrCode.ERR_1);
	}

	//门店导购列表
	@RequestMapping("store-clerk-list")
	public HaobanResponse storeClerkList(String storeId,String wxEnterpriseId){
		if(StringUtils.isAnyBlank(storeId,wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		StoreDTO store = storeService.getStore(storeId);
		if(store == null){
			return resultResponse(HaoBanErrCode.ERR_10009);
		}
		List<ClerkListDTO> list = clerkService.getClerkByStoreId(store.getEnterpriseId(), storeId);
		Set<String> clerkCodeList = list.stream().map(ClerkListDTO::getClerkCode).collect(Collectors.toSet());
		List<StaffClerkRelationDTO> bindRelationList = staffClerkRelationApiService.listBindCode(store.getEnterpriseId(),clerkCodeList);
		Map<String,StaffClerkRelationDTO> bindCodeMap = bindRelationList.stream().collect(Collectors.toMap(StaffClerkRelationDTO::getClerkCode, s->s));
		List<BindClerkVO> bindList = new ArrayList<>();
		List<BindClerkVO> unBindList = new ArrayList<>();
		for (ClerkListDTO clerkListDTO : list) {
			BindClerkVO vo = EntityUtil.changeEntityByJSON(BindClerkVO.class, clerkListDTO);
			if(bindCodeMap.keySet().contains(clerkListDTO.getClerkCode())){
				String staffId = bindCodeMap.get(clerkListDTO.getClerkCode()).getStaffId();
				StaffDTO staffDTO = staffApiService.selectById(staffId);
				vo.setStaffId(staffId);
				vo.setNationCode(clerkListDTO.getNationcode());
				vo.setPhoneNumber(clerkListDTO.getPhoneNumber());
				vo.setStaffName(staffDTO == null?"":staffDTO.getStaffName());
				bindList.add(vo);
			}else{
				unBindList.add(vo);
			}
		}
		Map<String,Object> map = new HashMap<>();
		map.put("bindList", bindList);
		map.put("unBindList", unBindList);
		return resultResponse(HaoBanErrCode.ERR_1,map);
		
	}
	
	//门店列表
	@RequestMapping("staff-store-list")
	public HaobanResponse staffStoreList(String staffId,String wxEnterpriseId){
		if(StringUtils.isAnyBlank(staffId,wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		List<StaffStoreVO> list = new ArrayList<>();
		List<EnterpriseDetailDTO> enterpriseList = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(wxEnterpriseId);
		List<String> enterpriseIdList = enterpriseList.stream().map(EnterpriseDetailDTO::getEnterpriseId).collect(Collectors.toList());
		List<StaffClerkRelationDTO> bindRelationList = staffClerkRelationApiService.listBindCodeByStaffId(enterpriseIdList, staffId);
		//主门店
		ClerkMainStoreRelatedDTO mainDTO = clerkMainStoreRelatedApiService.getWxEnterpriseIdAndStaffId(wxEnterpriseId, staffId);
		String storeId = mainDTO == null?"":mainDTO.getStoreId();
		for (StaffClerkRelationDTO staffClerkRelationDTO : bindRelationList) {
			ClerkDTO clerk = clerkService.getClerkByClerkCode(staffClerkRelationDTO.getEnterpriseId(), staffClerkRelationDTO.getClerkCode());
			if(clerk != null){
				StoreDTO store = storeService.getStore(clerk.getStoreId());
				//主门店标志
				int mainStoreFlag  = 0;
				if(StringUtils.isEmpty(storeId)){
					mainStoreFlag = 0;
				}else if(storeId.equals(store.getStoreId())){
					mainStoreFlag = 1;
				}
				staffDepartmentRelatedApiService.listByStaffId(staffId);
				StaffStoreVO vo = new StaffStoreVO();
				vo.setClerkCode(clerk.getClerkCode());
				vo.setClerkId(clerk.getClerkId());
				vo.setClerkType(clerk.getClerkType());
				vo.setEnterpriseId(clerk.getEnterpriseId());
				vo.setMainStoreFlag(mainStoreFlag);
				vo.setPhoneNumber(clerk.getPhoneNumber());
				vo.setStaffId(staffId);
				vo.setStoreId(clerk.getStoreId());
				vo.setStoreImg(store.getStoreImage());
				vo.setStoreName(store.getStoreName());
				vo.setWxEnterpriseId(wxEnterpriseId);
				list.add(vo);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,list);
		
	}
}
